Class: Tags

Inherits:
Hash
  • Object
show all
Defined in:
lib/stream2tracks/stream.rb

Overview

A Stream is an abstraction of the input audio stream container that has:

  • a path, either a URI or filename
  • a key, uniquely identifying the stream
  • some metadata about the stream (Tags)
  • some entries

Tags are metadata about a stream, its entries or a Track

A Track is separate entry from a stream, containing:

  • some metadata about the track (Tags)
  • a URI

A TrackFile is a file produced from a stream, containing:

  • some metadata about the track (Tags)
  • the filename
  • the format of the file